# -*- coding: UTF-8 -*-

# Phatch - Photo Batch Processor
# Copyright (C) 2007-2008 www.stani.be
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see http://www.gnu.org/licenses/
#
# Phatch recommends SPE (http://pythonide.stani.be) for editing python files.
import os
import sys
import wx
from core import ct
from core.api import import_module

ID_droplet = wx.ID_FORWARD

def install_frame(frame):
    try:
        droplet  = import_module('droplet',ct.PLATFORM)#os.path.join('lib',ct.PLATFORM))
    except:
        droplet  = None
    if droplet:
        droplet.install(frame)
    else:
        pass
